[Pcsclite-cvs-commit] r6243 - /trunk/Drivers/ccid/src/commands.c

rousseau at users.alioth.debian.org rousseau at users.alioth.debian.org
Fri Mar 23 08:35:09 UTC 2012


Author: rousseau
Date: Fri Mar 23 08:35:08 2012
New Revision: 6243

URL: http://svn.debian.org/wsvn/pcsclite/?sc=1&rev=6243
Log:
SecurePINVerify(): set the minimum timeout to 90 seconds

Some readers have a default timeout of 60 seconds. We need to use a
larger value to timeout _after_ the reader.

Modified:
    trunk/Drivers/ccid/src/commands.c

Modified: trunk/Drivers/ccid/src/commands.c
URL: http://svn.debian.org/wsvn/pcsclite/trunk/Drivers/ccid/src/commands.c?rev=6243&op=diff
==============================================================================
--- trunk/Drivers/ccid/src/commands.c (original)
+++ trunk/Drivers/ccid/src/commands.c Fri Mar 23 08:35:08 2012
@@ -463,7 +463,7 @@
 	i2dw(a - 10, cmd + 1);  /* CCID message length */
 
 	old_read_timeout = ccid_descriptor -> readTimeout;
-	ccid_descriptor -> readTimeout = max(30, TxBuffer[0]+10)*1000;	/* at least 30 seconds */
+	ccid_descriptor -> readTimeout = max(90, TxBuffer[0]+10)*1000;	/* at least 90 seconds */
 
 	if (WritePort(reader_index, a, cmd) != STATUS_SUCCESS)
 	{




More information about the Pcsclite-cvs-commit mailing list